summaryrefslogtreecommitdiffhomepage
path: root/cheatsheet/raylib_structs.c
diff options
context:
space:
mode:
authorRay <[email protected]>2018-07-15 21:26:53 +0200
committerRay <[email protected]>2018-07-15 21:26:53 +0200
commit055b0583d6096a0b621816a9374c412f1e929d3c (patch)
treedfaa3889823d9964e288ef86091fa0b90d8c69df /cheatsheet/raylib_structs.c
parent0a86a8aba37278723138647c4894fd89963195af (diff)
downloadraylib.com-055b0583d6096a0b621816a9374c412f1e929d3c.tar.gz
raylib.com-055b0583d6096a0b621816a9374c412f1e929d3c.zip
Updated cheatsheet
Diffstat (limited to 'cheatsheet/raylib_structs.c')
-rw-r--r--cheatsheet/raylib_structs.c10
1 files changed, 6 insertions, 4 deletions
diff --git a/cheatsheet/raylib_structs.c b/cheatsheet/raylib_structs.c
index 0929215..79edc85 100644
--- a/cheatsheet/raylib_structs.c
+++ b/cheatsheet/raylib_structs.c
@@ -3,15 +3,17 @@
struct Rectangle; // Rectangle type
struct Vector2; // Vector2 type
struct Vector3; // Vector3 type
+ struct Vector4; // Vector4 type
+ struct Quaternion; // Quaternion type
struct Matrix; // Matrix type (OpenGL style 4x4)
struct Image; // Image type (multiple data formats supported)
// NOTE: Data stored in CPU memory (RAM)
- struct Texture2D; // Texture2D type (multiple internal formats supported)
+ struct Texture; // Texture type (multiple internal formats supported)
// NOTE: Data stored in GPU memory (VRAM)
- struct RenderTexture2D; // RenderTexture2D type, for texture rendering
- struct CharInfo; // SpriteFont character info
- struct SpriteFont; // SpriteFont type, includes texture and chars data
+ struct RenderTexture; // RenderTexture type, for texture rendering
+ struct CharInfo; // Font character info
+ struct Font; // Font type, includes texture and chars data
struct Camera; // Camera type, defines 3d camera position/orientation
struct Camera2D; // Camera2D type, defines a 2d camera